@@ -37,11 +37,13 @@
 #include "baobab-treemap.h"
 #include "baobab-ringschart.h"
 
-#define BAOBAB_UI_FILE PKGDATADIR "/baobab-main-window.ui"
+#define BAOBAB_UI_RESOURCE "/org/mate/disk-usage-analyzer/baobab-main-window.ui"
 
 static void push_iter_in_stack (GtkTreeIter *);
 static GtkTreeIter pop_iter_from_stack (void);
 
+BaobabApplication baobab;
+
 static gint currentdepth = 0;
 static GtkTreeIter currentiter;
 static GtkTreeIter firstiter;
@@ -177,7 +179,7 @@ update_scan_label (void)
 		total = g_format_size (baobab.fs.total);
 		used = g_format_size (baobab.fs.used);
 		available = g_format_size (baobab.fs.avail);
-	
+
 	/* Translators: these are labels for disk space */
 	markup = g_markup_printf_escaped  ("<small>%s <b>%s</b> (%s %s %s %s)</small>",
 					   _("Total filesystem capacity:"), total,
@@ -402,9 +404,9 @@ first_row (void)
 
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), FALSE);
 	gtk_tree_store_append (baobab.model, &firstiter, &root_iter);
-	
+
 		size = g_format_size (baobab.fs.used);
-		
+
 	if (baobab.fs.total == 0 && baobab.fs.used == 0) {
 		perc = 100.0;
 	} else {
@@ -452,7 +454,7 @@ baobab_fill_model (struct chan_data *data)
 	hardlinks = g_string_new ("");
 	if (data->tempHLsize > 0) {
 			size = g_format_size (data->tempHLsize);
-			
+
 		g_string_assign (hardlinks, "<i>(");
 		g_string_append (hardlinks, _("contains hardlinks for:"));
 		g_string_append (hardlinks, " ");
@@ -646,7 +648,6 @@ baobab_create_toolbar (void)
 	GtkWidget *toolbar;
 	GtkToolItem *item;
 	GtkToolItem *separator;
-	gboolean visible;
 
 	toolbar = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "toolbar1"));
 	if (toolbar == NULL) {
@@ -686,8 +687,6 @@ baobab_create_toolbar (void)
 static void
 baobab_create_statusbar (void)
 {
-	gboolean visible;
-
 	baobab.statusbar = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui,
 							       "statusbar1"));
 	if (baobab.statusbar == NULL) {
@@ -846,9 +845,7 @@ baobab_init (void)
 
 	/* Load the UI */
 	baobab.main_ui = gtk_builder_new ();
-	gtk_builder_add_from_file (baobab.main_ui, BAOBAB_UI_FILE, &error);
-
-	if (error) {
+	if (gtk_builder_add_from_resource (baobab.main_ui, BAOBAB_UI_RESOURCE, &error) == 0) {
 		g_object_unref (baobab.main_ui);
 		g_critical ("Unable to load the user interface file: %s", error->message);
 		g_error_free (error);
@@ -860,7 +857,7 @@ baobab_init (void)
 	/* Settings */
 	baobab.ui_settings = g_settings_new (BAOBAB_UI_SETTINGS_SCHEMA);
 	baobab.prefs_settings = g_settings_new (BAOBAB_PREFS_SETTINGS_SCHEMA);
-	
+
 	/* Misc */
 	baobab.CONTENTS_CHANGED_DELAYED = FALSE;
 	baobab.STOP_SCANNING = TRUE;
