@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA  02110-1301  USA
  */
 
@@ -99,7 +99,7 @@ struct _BaobabApplication {
 };
 
 /* Application singleton */
-BaobabApplication baobab;
+extern BaobabApplication baobab;
 
 struct chan_data {
 	guint64 size;
