@@ -897,11 +897,7 @@ get_themed_icon_pixbuf (GThemedIcon * icon,
 		g_clear_error (&error);
 	}
 
-#if GTK_CHECK_VERSION (3, 8, 0)
 	g_object_unref (icon_info);
-#else
-	gtk_icon_info_free (icon_info);
-#endif
 	g_strfreev (icon_names);
 
 	return pixbuf;
@@ -952,10 +948,8 @@ open_file_with_filemanager (GtkWidget * window,
 	GDesktopAppInfo * d_app_info;
 	GKeyFile * key_file;
 	GdkAppLaunchContext * ctx = NULL;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkScreen *screen;
 	GdkDisplay *display;
-#endif
 	GList * list = NULL;
 	GAppInfo * g_app_info;
 	GFile * g_file;
@@ -995,13 +989,9 @@ open_file_with_filemanager (GtkWidget * window,
 	d_app_info = g_desktop_app_info_new_from_keyfile (key_file);
 
 	if (d_app_info != NULL) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 		screen = gtk_widget_get_screen (GTK_WIDGET (window));
 		display = gdk_screen_get_display (screen);
 		ctx = gdk_display_get_app_launch_context (display);
-#else
-		ctx = gdk_app_launch_context_new ();
-#endif
 		gdk_app_launch_context_set_screen (ctx, gtk_widget_get_screen (window));
 
 		result = g_app_info_launch_uris (G_APP_INFO (d_app_info), list,  G_APP_LAUNCH_CONTEXT (ctx), NULL);
@@ -1029,9 +1019,7 @@ open_file_with_application (GtkWidget * window,
                             GAppInfo * app)
 {
 	GdkAppLaunchContext * context;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkDisplay *display;
-#endif
 	GdkScreen * screen;
 	gboolean result;
 
@@ -1040,12 +1028,8 @@ open_file_with_application (GtkWidget * window,
 	}
 
 	screen = gtk_widget_get_screen (window);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display = gdk_screen_get_display (screen);
 	context = gdk_display_get_app_launch_context (display);
-#else
-	context = gdk_app_launch_context_new ();
-#endif
 	gdk_app_launch_context_set_screen (context, screen);
 
 	if (app == NULL) {
@@ -1133,10 +1117,9 @@ gsearchtool_get_unique_filename (const gchar * path,
 }
 
 GtkWidget *
-gsearchtool_button_new_with_stock_icon (const gchar * string,
-                                        const gchar * stock_id)
+gsearchtool_button_new_with_icon (const gchar * string,
+                                  const gchar * icon_name)
 {
-	GtkWidget * align;
 	GtkWidget * button;
 	GtkWidget * hbox;
 	GtkWidget * image;
@@ -1145,18 +1128,12 @@ gsearchtool_button_new_with_stock_icon (const gchar * string,
 	button = gtk_button_new ();
 	label = gtk_label_new_with_mnemonic (string);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-#if GTK_CHECK_VERSION (3, 0, 0)
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON);
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-#else
-	hbox = gtk_hbox_new (FALSE, 2);
-#endif
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-	gtk_widget_show_all (align);
+	gtk_container_add (GTK_CONTAINER (button), hbox);
+	gtk_widget_show_all (hbox);
 
 	return button;
 }
