@@ -27,7 +27,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#define UI_FILE LOGVIEW_DATADIR "/logview-filter.ui"
+#define UI_RESOURCE "/org/mate/system-log/logview-filter.ui"
 
 struct _LogviewFilterManagerPrivate {
   GtkWidget *tree;
@@ -48,10 +48,7 @@ enum {
   N_COLUMNS
 };
 
-#define LOGVIEW_FILTER_MANAGER_GET_PRIVATE(o)  \
-(G_TYPE_INSTANCE_GET_PRIVATE ((o), LOGVIEW_TYPE_FILTER_MANAGER, LogviewFilterManagerPrivate))
-
-G_DEFINE_TYPE (LogviewFilterManager, logview_filter_manager, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE_WITH_PRIVATE (LogviewFilterManager, logview_filter_manager, GTK_TYPE_DIALOG);
 
 static void
 logview_filter_manager_update_model (LogviewFilterManager *manager)
@@ -63,7 +60,7 @@ logview_filter_manager_update_model (LogviewFilterManager *manager)
 
   gtk_list_store_clear (GTK_LIST_STORE (manager->priv->model));
 
-  filters = logview_prefs_get_filters (manager->priv->prefs);  
+  filters = logview_prefs_get_filters (manager->priv->prefs);
 
   for (filter = filters; filter != NULL; filter = g_list_next (filter)) {
     g_object_get (filter->data, "name", &name, NULL);
@@ -78,7 +75,7 @@ logview_filter_manager_update_model (LogviewFilterManager *manager)
     g_free (name);
   }
 
-  g_list_free (filters);  
+  g_list_free (filters);
 }
 
 static gboolean
@@ -161,7 +158,7 @@ check_regex (LogviewFilterManager *manager, const gchar *regex)
 static void
 on_check_toggled (GtkToggleButton *button, GtkWidget *widget)
 {
-  gtk_widget_set_sensitive (widget, 
+  gtk_widget_set_sensitive (widget,
                             gtk_toggle_button_get_active (button));
 }
 
@@ -170,7 +167,7 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
                             LogviewFilterManager *manager)
 {
   GtkWidget *entry_name, *entry_regex;
-  GtkWidget *radio_color, *radio_visible;
+  GtkWidget *radio_color;
   GtkWidget *check_foreground, *check_background;
   GtkWidget *color_foreground, *color_background;
   gchar *old_name;
@@ -189,8 +186,6 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
                                                     "entry_regex"));
   radio_color = GTK_WIDGET (gtk_builder_get_object (builder,
                                                     "radio_color"));
-  radio_visible = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                      "radio_visible"));
   check_foreground = GTK_WIDGET (gtk_builder_get_object (builder,
                                                          "check_foreground"));
   check_background = GTK_WIDGET (gtk_builder_get_object (builder,
@@ -216,7 +211,7 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
         GdkRGBA foreground_color;
         gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (color_foreground),
                                     &foreground_color);
-        g_object_set (G_OBJECT (tag), 
+        g_object_set (G_OBJECT (tag),
                       "foreground-rgba", &foreground_color,
                       "foreground-set", TRUE, NULL);
       }
@@ -225,11 +220,11 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
         GdkRGBA background_color;
         gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (color_background),
                                     &background_color);
-        g_object_set (tag, 
+        g_object_set (tag,
                       "paragraph-background-rgba", &background_color,
                       "paragraph-background-set", TRUE, NULL);
       }
-      
+
       if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_foreground))
           && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_background))) {
           GtkWidget *error_dialog;
@@ -284,10 +279,8 @@ run_add_edit_dialog (LogviewFilterManager *manager, LogviewFilter *filter)
 
   error = NULL;
   name = NULL;
-  
-  gtk_builder_add_from_file (builder, UI_FILE, &error);
 
-  if (error) {
+  if (gtk_builder_add_from_resource (builder, UI_RESOURCE, &error) == 0) {
     g_warning ("Could not load filter ui: %s", error->message);
     g_error_free (error);
     return;
@@ -397,7 +390,7 @@ run_add_edit_dialog (LogviewFilterManager *manager, LogviewFilter *filter)
 
 static void
 on_add_clicked (GtkWidget *button, LogviewFilterManager *manager)
-{                                                   
+{
   run_add_edit_dialog (manager, NULL);
 }
 
@@ -428,7 +421,7 @@ on_remove_clicked (GtkWidget *button, LogviewFilterManager *manager)
   GtkTreeModel *model;
   gchar *name;
 
-  selection  = 
+  selection  =
     gtk_tree_view_get_selection (GTK_TREE_VIEW (manager->priv->tree));
 
   gtk_tree_selection_get_selected (selection, &model, &iter);
@@ -448,7 +441,7 @@ on_tree_selection_changed (GtkTreeSelection *selection, LogviewFilterManager *ma
   status = gtk_tree_selection_get_selected (selection, NULL, NULL);
 
   gtk_widget_set_sensitive (manager->priv->edit_button, status);
-  gtk_widget_set_sensitive (manager->priv->remove_button, status);	
+  gtk_widget_set_sensitive (manager->priv->remove_button, status);
 }
 
 static void
@@ -460,7 +453,7 @@ logview_filter_manager_init (LogviewFilterManager *manager)
   GtkCellRenderer *text_renderer;
   LogviewFilterManagerPrivate *priv;
 
-  manager->priv = LOGVIEW_FILTER_MANAGER_GET_PRIVATE (manager);
+  manager->priv = logview_filter_manager_get_instance_private (manager);
   priv = manager->priv;
 
   priv->builder = gtk_builder_new ();
@@ -523,11 +516,11 @@ logview_filter_manager_init (LogviewFilterManager *manager)
   gtk_window_set_title (GTK_WINDOW (manager),
                         _("Filters"));
 
-  g_signal_connect (priv->add_button, "clicked", 
+  g_signal_connect (priv->add_button, "clicked",
                     G_CALLBACK (on_add_clicked), manager);
-  g_signal_connect (priv->edit_button, "clicked", 
+  g_signal_connect (priv->edit_button, "clicked",
                     G_CALLBACK (on_edit_clicked), manager);
-  g_signal_connect (priv->remove_button, "clicked", 
+  g_signal_connect (priv->remove_button, "clicked",
                     G_CALLBACK (on_remove_clicked), manager);
 
   gtk_widget_set_sensitive (priv->edit_button, FALSE);
@@ -575,8 +568,6 @@ logview_filter_manager_class_init (LogviewFilterManagerClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkDialogClass *parent_class = GTK_DIALOG_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (LogviewFilterManagerPrivate));
-
   object_class->dispose = logview_filter_manager_dispose;
   parent_class->response = logview_filter_manager_response;
 }
