@@ -46,7 +46,7 @@ struct _LogviewWindowPrivate {
 
   GtkWidget *find_bar;
   GtkWidget *loglist;
-  GtkWidget *sidebar; 
+  GtkWidget *sidebar;
   GtkWidget *version_bar;
   GtkWidget *version_selector;
   GtkWidget *hpaned;
@@ -74,10 +74,7 @@ struct _LogviewWindowPrivate {
   gboolean matches_only;
 };
 
-#define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), LOGVIEW_TYPE_WINDOW, LogviewWindowPrivate))
-
-G_DEFINE_TYPE (LogviewWindow, logview_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE_WITH_PRIVATE (LogviewWindow, logview_window, GTK_TYPE_WINDOW);
 
 static void findbar_close_cb  (LogviewFindbar *findbar,
                                gpointer user_data);
@@ -129,7 +126,7 @@ static void
 populate_tag_table (GtkTextTagTable *tag_table)
 {
   GtkTextTag *tag;
-  
+
   tag = gtk_text_tag_new ("bold");
   g_object_set (tag, "weight", PANGO_WEIGHT_BOLD,
                 "weight-set", TRUE, NULL);
@@ -142,7 +139,7 @@ populate_tag_table (GtkTextTagTable *tag_table)
 
   tag = gtk_text_tag_new ("invisible-filter");
   g_object_set (tag, "invisible", TRUE, "invisible-set", TRUE, NULL);
-  gtk_text_tag_table_add (tag_table, tag); 
+  gtk_text_tag_table_add (tag_table, tag);
 }
 
 static void
@@ -200,10 +197,10 @@ _gtk_text_buffer_apply_tag_to_rectangle (GtkTextBuffer *buffer, int line_start,
 static void
 logview_update_statusbar (LogviewWindow *logview, LogviewLog *active)
 {
+  GDateTime *date_time;
   char *statusbar_text;
-  char *size, *modified, *timestring_utf8;
+  char *size, *modified, *timestring;
   time_t timestamp;
-  char timestring[255];
 
   if (active == NULL) {
     gtk_statusbar_pop (GTK_STATUSBAR (logview->priv->statusbar), 0);
@@ -211,24 +208,24 @@ logview_update_statusbar (LogviewWindow *logview, LogviewLog *active)
   }
 
   timestamp = logview_log_get_timestamp (active);
-  strftime (timestring, sizeof (timestring), "%a %b %e %T %Y", localtime (&timestamp));
-  timestring_utf8 = g_locale_to_utf8 (timestring, -1, NULL, NULL, NULL);
+  date_time = g_date_time_new_from_unix_local (timestamp);
+  timestring = g_date_time_format (date_time, "%c");
+  modified = g_strdup_printf (_("last update: %s"), timestring);
 
-  modified = g_strdup_printf (_("last update: %s"), timestring_utf8);
+  size = g_format_size (logview_log_get_file_size (active));
 
-    size = g_format_size (logview_log_get_file_size (active));
-  
-  statusbar_text = g_strdup_printf (_("%d lines (%s) - %s"), 
+  statusbar_text = g_strdup_printf (_("%d lines (%s) - %s"),
                                     logview_log_get_cached_lines_number (active),
                                     size, modified);
 
   gtk_statusbar_pop (GTK_STATUSBAR (logview->priv->statusbar), 0);
   gtk_statusbar_push (GTK_STATUSBAR (logview->priv->statusbar), 0, statusbar_text);
-  
+
   g_free (size);
-  g_free (timestring_utf8);
+  g_free (timestring);
   g_free (modified);
   g_free (statusbar_text);
+  g_date_time_unref (date_time);
 }
 
 #define DEFAULT_LOGVIEW_FONT "Monospace 10"
@@ -371,14 +368,14 @@ logview_bigger_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MIN (logview->priv->fontsize + 1, 24);
   logview_set_fontsize (logview, TRUE);
-}	
+}
 
 static void
 logview_smaller_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MAX (logview->priv->fontsize-1, 6);
   logview_set_fontsize (logview, TRUE);
-}	
+}
 
 static void
 logview_normal_text (GtkAction *action, LogviewWindow *logview)
@@ -479,7 +476,7 @@ wrap:
     }
   } else {
     if (wrapped) {
-      
+
       GtkTextMark *mark;
       GtkTextIter iter;
 
@@ -535,7 +532,7 @@ text_changed_timeout_cb (gpointer user_data)
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (logview->priv->text_view));
   search_start = gtk_text_buffer_get_mark (buffer, SEARCH_START_MARK);
   search_end = gtk_text_buffer_get_mark (buffer, SEARCH_END_MARK);
-  
+
   if (search_start) {
     /* reset the search mark to the start */
     gtk_text_buffer_get_start_iter (buffer, &start);
@@ -595,7 +592,7 @@ filter_buffer (LogviewWindow *logview, gint start_line)
          cur_filter = g_list_next (cur_filter))
     {
       if (logview_filter_filter (LOGVIEW_FILTER (cur_filter->data), text)) {
-        gtk_text_buffer_apply_tag (buffer, 
+        gtk_text_buffer_apply_tag (buffer,
                                    logview_filter_get_tag (LOGVIEW_FILTER (cur_filter->data)),
                                    &start, end);
         matched = TRUE;
@@ -605,7 +602,7 @@ filter_buffer (LogviewWindow *logview, gint start_line)
     g_free (text);
 
     if (!matched && logview->priv->matches_only) {
-      gtk_text_buffer_apply_tag_by_name (buffer, 
+      gtk_text_buffer_apply_tag_by_name (buffer,
                                          "invisible-filter",
                                          &start, end);
     } else {
@@ -621,7 +618,7 @@ filter_buffer (LogviewWindow *logview, gint start_line)
 static void
 filter_remove (LogviewWindow *logview, LogviewFilter *filter)
 {
-  GtkTextIter start, end;  
+  GtkTextIter start, end;
   GtkTextBuffer *buffer;
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (logview->priv->text_view));
@@ -634,12 +631,12 @@ filter_remove (LogviewWindow *logview, LogviewFilter *filter)
 static void
 on_filter_toggled (GtkToggleAction *action, LogviewWindow *logview)
 {
-  LogviewWindowPrivate *priv = GET_PRIVATE (logview);
+  LogviewWindowPrivate *priv = logview_window_get_instance_private (logview);
   const gchar* name;
   LogviewFilter *filter;
 
   name = gtk_action_get_name (GTK_ACTION (action));
-  
+
   if (gtk_toggle_action_get_active (action)) {
     priv->active_filters = g_list_append (priv->active_filters,
                                           logview_prefs_get_filter (priv->prefs,
@@ -663,18 +660,16 @@ update_filter_menu (LogviewWindow *window)
   GList *actions, *l;
   guint id;
   GList *filters;
-  GtkTextBuffer *buffer;
   GtkTextTagTable *table;
   GtkTextTag *tag;
   GtkToggleAction *action;
   gchar* name;
 
-  priv = GET_PRIVATE (window);
+  priv = logview_window_get_instance_private (window);
   ui = priv->ui_manager;
 
   g_return_if_fail (priv->filter_action_group != NULL);
 
-  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->text_view));
   table = priv->tag_table;
 
   if (priv->filter_merge_id != 0) {
@@ -696,7 +691,7 @@ update_filter_menu (LogviewWindow *window)
   }
 
   g_list_free (actions);
-  
+
   filters = logview_prefs_get_filters (logview_prefs_get ());
 
   id = (g_list_length (filters) > 0) ? gtk_ui_manager_new_merge_id (ui) : 0;
@@ -715,7 +710,7 @@ update_filter_menu (LogviewWindow *window)
 
     gtk_ui_manager_add_ui (ui, id, FILTER_PLACEHOLDER,
                            name, name, GTK_UI_MANAGER_MENUITEM, FALSE);
-    gtk_text_tag_table_add (table, 
+    gtk_text_tag_table_add (table,
                             logview_filter_get_tag (LOGVIEW_FILTER (l->data)));
 
     g_object_unref (action);
@@ -728,7 +723,7 @@ update_filter_menu (LogviewWindow *window)
 }
 
 static void
-on_logview_filter_manager_response (GtkDialog *dialog, 
+on_logview_filter_manager_response (GtkDialog *dialog,
                                     gint response,
                                     LogviewWindow *logview)
 {
@@ -745,10 +740,10 @@ logview_manage_filters (GtkAction *action, LogviewWindow *logview)
 
   manager = logview_filter_manager_new ();
 
-  g_signal_connect (manager, "response", 
+  g_signal_connect (manager, "response",
                     G_CALLBACK (on_logview_filter_manager_response),
                     logview);
-  
+
   gtk_window_set_transient_for (GTK_WINDOW (manager),
                                 GTK_WINDOW (logview));
   gtk_widget_show (GTK_WIDGET (manager));
@@ -774,7 +769,7 @@ logview_about (GtkWidget *widget, GtkWidget *window)
                          "version", VERSION,
                          "title", _("About System Log Viewer"),
                          "copyright", _("Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.\n"
-                                        "Copyright \xc2\xa9 2011-2019 MATE developers"),
+                                        "Copyright \xc2\xa9 2011-2020 MATE developers"),
                          "license", license_trans,
                          "wrap-license", TRUE,
                          "comments", _("A system log viewer for MATE."),
@@ -823,14 +818,14 @@ static GtkActionEntry entries[] = {
     { "FileMenu", NULL, N_("_File"), NULL, NULL, NULL },
     { "EditMenu", NULL, N_("_Edit"), NULL, NULL, NULL },
     { "ViewMenu", NULL, N_("_View"), NULL, NULL, NULL },
-    { "FilterMenu", NULL, N_("_Filters"), NULL, NULL, NULL },  
+    { "FilterMenu", NULL, N_("_Filters"), NULL, NULL, NULL },
     { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 
-    { "OpenLog", "document-open", N_("_Open..."), "<control>O", N_("Open a log from file"), 
+    { "OpenLog", "document-open", N_("_Open..."), "<control>O", N_("Open a log from file"),
       G_CALLBACK (logview_open_log) },
-    { "CloseLog", "window-close", N_("_Close"), "<control>W", N_("Close this log"), 
+    { "CloseLog", "window-close", N_("_Close"), "<control>W", N_("Close this log"),
       G_CALLBACK (logview_close_log) },
-    { "Quit", "application-exit", N_("_Quit"), "<control>Q", N_("Quit the log viewer"), 
+    { "Quit", "application-exit", N_("_Quit"), "<control>Q", N_("Quit the log viewer"),
       G_CALLBACK (gtk_main_quit) },
 
     { "Copy", "edit-copy", N_("_Copy"), "<control>C", N_("Copy the selection"),
@@ -849,24 +844,24 @@ static GtkActionEntry entries[] = {
 
     { "FilterManage", NULL, N_("Manage Filters"), NULL, N_("Manage filters"),
       G_CALLBACK (logview_manage_filters)},
-  
-    { "HelpContents", "help-browser", N_("_Contents"), "F1", N_("Open the help contents for the log viewer"), 
+
+    { "HelpContents", "help-browser", N_("_Contents"), "F1", N_("Open the help contents for the log viewer"),
       G_CALLBACK (logview_help) },
-    { "AboutAction", "help-about", N_("_About"), NULL, N_("Show the about dialog for the log viewer"), 
+    { "AboutAction", "help-about", N_("_About"), NULL, N_("Show the about dialog for the log viewer"),
       G_CALLBACK (logview_about) },
 };
 
 static GtkToggleActionEntry toggle_entries[] = {
     { "ShowStatusBar", NULL, N_("_Statusbar"), NULL, N_("Show Status Bar"),
       G_CALLBACK (logview_toggle_statusbar), TRUE },
-    { "ShowSidebar", NULL, N_("Side _Pane"), "F9", N_("Show Side Pane"), 
-      G_CALLBACK (logview_toggle_sidebar), TRUE }, 
+    { "ShowSidebar", NULL, N_("Side _Pane"), "F9", N_("Show Side Pane"),
+      G_CALLBACK (logview_toggle_sidebar), TRUE },
     { "FilterMatchOnly", NULL, N_("Show matches only"), NULL, N_("Only show lines that match one of the given filters"),
       G_CALLBACK (logview_toggle_match_filters), FALSE}
 };
 
-static gboolean 
-window_size_changed_cb (GtkWidget *widget, GdkEventConfigure *event, 
+static gboolean
+window_size_changed_cb (GtkWidget *widget, GdkEventConfigure *event,
                         gpointer data)
 {
   LogviewWindow *window = data;
@@ -1183,7 +1178,7 @@ message_area_create_error_box (LogviewWindow *window,
   GtkWidget *vbox;
   GtkWidget *primary_label;
   GtkWidget *secondary_label;
-  
+
   hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
   gtk_widget_show (hbox_content);
 
@@ -1292,7 +1287,7 @@ logview_window_init (LogviewWindow *logview)
   s_context = gtk_widget_get_style_context (GTK_WIDGET (logview));
   gtk_style_context_add_class (s_context, "logview-window");
 
-  priv = logview->priv = GET_PRIVATE (logview);
+  priv = logview->priv = logview_window_get_instance_private (logview);
   priv->prefs = logview_prefs_get ();
   priv->manager = logview_manager_get ();
   priv->monitor_id = 0;
@@ -1316,9 +1311,9 @@ logview_window_init (LogviewWindow *logview)
   accel_group = gtk_ui_manager_get_accel_group (priv->ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (logview), accel_group);
 
-  res = gtk_ui_manager_add_ui_from_file (priv->ui_manager,
-                                         LOGVIEW_DATADIR "/logview-toolbar.xml",
-                                         &error);
+  res = gtk_ui_manager_add_ui_from_resource (priv->ui_manager,
+                                             "/org/mate/system-log/logview-toolbar.xml",
+                                             &error);
 
   if (res == FALSE) {
     priv->ui_manager = NULL;
@@ -1333,7 +1328,7 @@ logview_window_init (LogviewWindow *logview)
   w = gtk_ui_manager_get_widget (priv->ui_manager, "/LogviewMenu");
   gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
   gtk_widget_show (w);
-  
+
   /* panes */
   hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start (GTK_BOX (vbox), hpaned, TRUE, TRUE, 0);
@@ -1464,7 +1459,7 @@ logview_window_init (LogviewWindow *logview)
                                       1);
   priv->active_filters = NULL;
   update_filter_menu (logview);
-  
+
   gtk_widget_show (vbox);
   gtk_widget_show (main_view);
 }
@@ -1475,8 +1470,6 @@ logview_window_class_init (LogviewWindowClass *klass)
   GObjectClass *object_class = (GObjectClass *) klass;
 
   object_class->finalize = logview_window_finalize;
-
-  g_type_class_add_private (klass, sizeof (LogviewWindowPrivate));
 }
 
 /* public methods */
@@ -1506,7 +1499,7 @@ logview_window_add_error (LogviewWindow *window,
   priv = window->priv;
 
   message_area_set_labels (window,
-                           primary, secondary); 
+                           primary, secondary);
 
   gtk_widget_show (priv->message_area);
 
