@@ -16,15 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #ifndef __GDICT_COMMON_H__
 #define __GDICT_COMMON_H__
 
 #include <gtk/gtk.h>
-#include <mateconf/mateconf-client.h>
 
 G_BEGIN_DECLS
 
@@ -38,11 +37,6 @@ void     gdict_show_gerror_dialog (GtkWindow   *parent,
 				   const gchar *message,
 				   GError      *error);
 
-gchar *  gdict_mateconf_get_string_with_default (MateConfClient *client,
-					      const gchar *key,
-					      const gchar *def);
-
-
 G_END_DECLS
 
 #endif /* __GDICT_COMMON_H__ */
